abacusai.api_class.dataset_application_connector — AbacusAI documentation

# abacusai.api_class.dataset_application_connector

## Classes

`ApplicationConnectorDatasetConfig` | An abstract class for dataset configs specific to application connectors.
`ConfluenceDatasetConfig` | Dataset config for Confluence Application Connector
`BoxDatasetConfig` | Dataset config for Box Application Connector
`GoogleAnalyticsDatasetConfig` | Dataset config for Google Analytics Application Connector
`GoogleDriveDatasetConfig` | Dataset config for Google Drive Application Connector
`JiraDatasetConfig` | Dataset config for Jira Application Connector
`OneDriveDatasetConfig` | Dataset config for OneDrive Application Connector
`SharepointDatasetConfig` | Dataset config for Sharepoint Application Connector
`ZendeskDatasetConfig` | Dataset config for Zendesk Application Connector
`AbacusUsageMetricsDatasetConfig` | Dataset config for Abacus Usage Metrics Application Connector
`TeamsScraperDatasetConfig` | Dataset config for Teams Scraper Application Connector
`OutlookDatasetConfig` | Dataset config for Outlook Application Connector
`FreshserviceDatasetConfig` | Dataset config for Freshservice Application Connector
`SftpDatasetConfig` | Dataset config for SFTP Application Connector
`_ApplicationConnectorDatasetConfigFactory` |

## Module Contents

class abacusai.api_class.dataset_application_connector.ApplicationConnectorDatasetConfig

  Bases: `abacusai.api_class.dataset.DatasetConfig`

  An abstract class for dataset configs specific to application connectors.

  Parameters:

    - application_connector_type (enums.ApplicationConnectorType) – The type of application connector

    - application_connector_id (str) – The ID of the application connector

    - document_processing_config (DatasetDocumentProcessingConfig) – The document processing configuration. Only valid if is_documentset is True for the dataset.

  application_connector_type: abacusai.api_class.enums.ApplicationConnectorType = None
  application_connector_id: str = None
  document_processing_config: abacusai.api_class.dataset.DatasetDocumentProcessingConfig = None
  classmethod _get_builder()

class abacusai.api_class.dataset_application_connector.ConfluenceDatasetConfig

  Bases: `ApplicationConnectorDatasetConfig`

  Dataset config for Confluence Application Connector :param location: The location of the pages to fetch :type location: str :param space_key: The space key of the space from which we fetch pages :type space_key: str :param pull_attachments: Whether to pull attachments for each page :type pull_attachments: bool :param extract_bounding_boxes: Whether to extract bounding boxes from the documents :type extract_bounding_boxes: bool :param location_type: The type of location to be fetched. Maps values in location to content type, example: ‘spaceKey/folderTitle/*’ -> ‘folder’ :type location_type: str

  location: str = None
  space_key: str = None
  pull_attachments: bool = False
  extract_bounding_boxes: bool = False
  location_type: str = None
  __post_init__()

class abacusai.api_class.dataset_application_connector.BoxDatasetConfig

  Bases: `ApplicationConnectorDatasetConfig`

  Dataset config for Box Application Connector :param location: The regex location of the files to fetch :type location: str :param csv_delimiter: If the file format is CSV, use a specific csv delimiter :type csv_delimiter: str :param merge_file_schemas: Signifies if the merge file schema policy is enabled. Not applicable if is_documentset is True :type merge_file_schemas: bool

  location: str = None
  csv_delimiter: str = None
  merge_file_schemas: bool = False
  __post_init__()

class abacusai.api_class.dataset_application_connector.GoogleAnalyticsDatasetConfig

  Bases: `ApplicationConnectorDatasetConfig`

  Dataset config for Google Analytics Application Connector

  Parameters:

    - location (str) – The view id of the report in the connector to fetch

    - start_timestamp (int) – Unix timestamp of the start of the period that will be queried

    - end_timestamp (int) – Unix timestamp of the end of the period that will be queried

  location: str = None
  start_timestamp: int = None
  end_timestamp: int = None
  __post_init__()

class abacusai.api_class.dataset_application_connector.GoogleDriveDatasetConfig

  Bases: `ApplicationConnectorDatasetConfig`

  Dataset config for Google Drive Application Connector

  Parameters:

    - location (str) – The regex location of the files to fetch

    - csv_delimiter (str) – If the file format is CSV, use a specific csv delimiter

    - extract_bounding_boxes (bool) – Signifies whether to extract bounding boxes out of the documents. Only valid if is_documentset if True

    - merge_file_schemas (bool) – Signifies if the merge file schema policy is enabled. Not applicable if is_documentset is True

    - location_type (str) – The type of path to fetch. ‘shared’ for shared files. if not provided, it will fetch from the root folder.

  location: str = None
  csv_delimiter: str = None
  extract_bounding_boxes: bool = False
  merge_file_schemas: bool = False
  location_type: str = None
  __post_init__()

class abacusai.api_class.dataset_application_connector.JiraDatasetConfig

  Bases: `ApplicationConnectorDatasetConfig`

  Dataset config for Jira Application Connector

  Parameters:

    - jql (str) – The JQL query for fetching issues

    - custom_fields (list) – A list of custom fields to include in the dataset

    - include_comments (bool) – Fetch comments for each issue

    - include_watchers (bool) – Fetch watchers for each issue

  jql: str = None
  custom_fields: list = None
  include_comments: bool = False
  include_watchers: bool = False
  __post_init__()

class abacusai.api_class.dataset_application_connector.OneDriveDatasetConfig

  Bases: `ApplicationConnectorDatasetConfig`

  Dataset config for OneDrive Application Connector

  Parameters:

    - location (str) – The regex location of the files to fetch

    - csv_delimiter (str) – If the file format is CSV, use a specific csv delimiter

    - extract_bounding_boxes (bool) – Signifies whether to extract bounding boxes out of the documents. Only valid if is_documentset if True

    - merge_file_schemas (bool) – Signifies if the merge file schema policy is enabled. Not applicable if is_documentset is True

  location: str = None
  csv_delimiter: str = None
  extract_bounding_boxes: bool = False
  merge_file_schemas: bool = False
  __post_init__()

class abacusai.api_class.dataset_application_connector.SharepointDatasetConfig

  Bases: `ApplicationConnectorDatasetConfig`

  Dataset config for Sharepoint Application Connector

  Parameters:

    - location (str) – The regex location of the files to fetch

    - csv_delimiter (str) – If the file format is CSV, use a specific csv delimiter

    - extract_bounding_boxes (bool) – Signifies whether to extract bounding boxes out of the documents. Only valid if is_documentset if True

    - merge_file_schemas (bool) – Signifies if the merge file schema policy is enabled. Not applicable if is_documentset is True

  location: str = None
  csv_delimiter: str = None
  extract_bounding_boxes: bool = False
  merge_file_schemas: bool = False
  __post_init__()

class abacusai.api_class.dataset_application_connector.ZendeskDatasetConfig

  Bases: `ApplicationConnectorDatasetConfig`

  Dataset config for Zendesk Application Connector

  Parameters:

    location (str) – The regex location of the files to fetch

  location: str = None
  __post_init__()

class abacusai.api_class.dataset_application_connector.AbacusUsageMetricsDatasetConfig

  Bases: `ApplicationConnectorDatasetConfig`

  Dataset config for Abacus Usage Metrics Application Connector

  Parameters:

    - include_entire_conversation_history (bool) – Whether to show the entire history for this deployment conversation

    - include_all_feedback (bool) – Whether to include all feedback for this deployment conversation

    - resolve_matching_documents (bool) – Whether to get matching document references for response instead of prompt. Needs to recalculate them if highlights are unavailable in summary_info

  include_entire_conversation_history: bool = False
  include_all_feedback: bool = False
  resolve_matching_documents: bool = False
  __post_init__()

class abacusai.api_class.dataset_application_connector.TeamsScraperDatasetConfig

  Bases: `ApplicationConnectorDatasetConfig`

  Dataset config for Teams Scraper Application Connector

  Parameters:

    - pull_chat_messages (bool) – Whether to pull teams chat messages

    - pull_channel_posts (bool) – Whether to pull posts for each channel

    - pull_transcripts (bool) – Whether to pull transcripts for calendar meetings

    - max_days_to_lookback (int) – The maximum number of days to look back for data

  pull_chat_messages: bool = False
  pull_channel_posts: bool = False
  pull_transcripts: bool = False
  max_days_to_lookback: int = 365
  __post_init__()

class abacusai.api_class.dataset_application_connector.OutlookDatasetConfig

  Bases: `ApplicationConnectorDatasetConfig`

  Dataset config for Outlook Application Connector

  __post_init__()

class abacusai.api_class.dataset_application_connector.FreshserviceDatasetConfig

  Bases: `ApplicationConnectorDatasetConfig`

  Dataset config for Freshservice Application Connector

  __post_init__()

class abacusai.api_class.dataset_application_connector.SftpDatasetConfig

  Bases: `ApplicationConnectorDatasetConfig`

  Dataset config for SFTP Application Connector

  Parameters:

    - location (str) – The regex location of the files to fetch

    - csv_delimiter (str) – If the file format is CSV, use a specific csv delimiter

    - extract_bounding_boxes (bool) – Signifies whether to extract bounding boxes out of the documents. Only valid if is_documentset if True

    - merge_file_schemas (bool) – Signifies if the merge file schema policy is enabled. Not applicable if is_documentset is True

  location: str = None
  csv_delimiter: str = None
  extract_bounding_boxes: bool = False
  merge_file_schemas: bool = False
  __post_init__()

class abacusai.api_class.dataset_application_connector._ApplicationConnectorDatasetConfigFactory

  Bases: `abacusai.api_class.abstract._ApiClassFactory`

  config_abstract_class
  config_class_key = 'application_connector_type'
  config_class_map